@@ -4,9 +4,9 @@
 ;;
 ;; Author: taku0 <mxxouy6x3m_github@tatapa.org>
 ;; Maintainer: taku0 <mxxouy6x3m_github@tatapa.org>
-;; Package-Version: 20250720.619
-;; Package-Revision: 38a3f1f11dd2
-;; Package-Requires: ((emacs "24.4") (json-mode "1.7.0"))
+;; Package-Version: 20260131.913
+;; Package-Revision: 1c0e363a8d28
+;; Package-Requires: ((emacs "24.4"))
 ;; Keywords: abbrev, convenience, files
 ;; URL: https://github.com/taku0/json-par
 
@@ -64,7 +64,6 @@
 ;;; Code:
 
 (require 'easymenu)
-(require 'json-mode)
 (require 'json-par-utils)
 (require 'json-par-keymap)
 (require 'json-par-lexer)
